MLQA (Multilingual Question Answering Dataset) is a benchmark dataset for
evaluating multilingual question answering performance. The dataset consists of
7 languages: Arabic, German, Spanish, English, Hindi, Vietnamese, Chinese.
